Documentation
¶
Overview ¶
Package deviceinfo provides the devices information for cos-gpu-installer
Index ¶
Constants ¶
const ( K80 GPUType = iota P4 P100 V100 L4 T4 H100 H200 B200 GB200 GB300 A100_40GB A100_80GB RTX_PRO_6000 NO_GPU Others NvidiaVendorID uint16 = 0x10de )
Variables ¶
var AllGPUTypeStrings = []string{
"NVIDIA_TESLA_K80",
"NVIDIA_TESLA_P4",
"NVIDIA_TESLA_P100",
"NVIDIA_TESLA_V100",
"NVIDIA_L4",
"NVIDIA_H100_80GB",
"NVIDIA_H200",
"NVIDIA_B200",
"NVIDIA_TESLA_A100",
"NVIDIA_A100_80GB",
"NVIDIA_TESLA_T4",
"NVIDIA_GB200",
"NVIDIA_GB300",
"NVIDIA_RTX_PRO_6000",
}
Functions ¶
This section is empty.
Types ¶
type GPU ¶
GPU represents a GPU device: type does it support vGPU, is it actually a vGPU
func AvailableGPUList ¶
AvailableGPUList returns a list of GPU devices supported based on the milestone
type GPUType ¶
type GPUType int
func GetGPUTypeInfo ¶
GetGPUTypeInfo finds the GPU device type by reading sysfs. It detects the PCI ID on the system and looks it up in the gpuTypeToPciIDs map.
func ParseGPUType ¶
ParseGPUType converts a string to a GPUType enum.
func (GPUType) OpenSupported ¶
TODO(gshuoy): b/331317222 - Add the open source supported in the proto file.
func (GPUType) SupportedArches ¶
TODO(gshuoy): b/331317222 - Add the arch support in the proto file. SupportedArches returns the list of supported architectures for the GPU type. Typically either "x86_64", "aarch64", or both (if future GPUs support both).